==> haskell-comonad-5.0.6-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: comonad
version: 5.0.6
id: comonad-5.0.6-8rsrtEd0xc7Zvn1LuwTgB
key: comonad-5.0.6-8rsrtEd0xc7Zvn1LuwTgB
license: BSD-3-Clause
copyright: Copyright (C) 2008-2014 Edward A. Kmett,
           Copyright (C) 2004-2008 Dave Menendez
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/comonad/
synopsis: Comonads
description:
    Comonads.
category: Control, Comonads
abi: 6a5963a9e4500b868ae45aad300de678
exposed: True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition
import-dirs: /usr/lib/ghc-8.6.5/site-local/comonad-5.0.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/comonad-5.0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/comonad-5.0.6
hs-libraries: HScomonad-5.0.6-8rsrtEd0xc7Zvn1LuwTgB
depends:
    base-4.12.0.0 containers-0.6.0.1
    distributive-0.6.1-BcPUpXmGYOcAFyhEcxFEaN
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html: /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-comonad-5.0.6-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: comonad
version: 5.0.6
id: comonad-5.0.6-7B6D6g1bSdc2clGN50pSDI
key: comonad-5.0.6-7B6D6g1bSdc2clGN50pSDI
license: BSD-3-Clause
copyright: Copyright (C) 2008-2014 Edward A. Kmett,
           Copyright (C) 2004-2008 Dave Menendez
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/comonad/
synopsis: Comonads
description:
    Comonads.
category: Control, Comonads
abi: 4f947af1265f9f39ab052ff069c42b87
exposed: True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition
import-dirs: /usr/lib/ghc-8.6.5/site-local/comonad-5.0.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/comonad-5.0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/comonad-5.0.6
hs-libraries: HScomonad-5.0.6-7B6D6g1bSdc2clGN50pSDI
depends:
    base-4.12.0.0 containers-0.6.0.1
    distributive-0.6.1-De7kMCQhjEH57FVUJVuxH5
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html: /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
